@@ -8,9 +8,14 @@ from io import StringIO, BytesIO
 from collections import defaultdict
 from pathlib import Path
 
-__version__ = '2.1.3'
+__version__ = '2.1.4'
 GLOBALS_KEY = '_globals'
 
+if os_name == 'nt':
+    SWITCH_CHARS = '-/'
+else:
+    SWITCH_CHARS = '-'
+
 
 def argv_to_dict(args: List[str], aliases: Dict[str, str] = None) -> DefaultDict[str, list]:
     """
@@ -31,7 +36,7 @@ def argv_to_dict(args: List[str], aliases: Dict[str, str] = None) -> DefaultDict
     result = defaultdict(list)
     for a in args:
         # arguments are prefixed with -, -- or / - no distinction for long names, so --h or -help would be valid
-        if len(a) > 0 and a[0] in '-/':
+        if len(a) > 0 and a[0] in SWITCH_CHARS:
             if len(a) == 1:
                 raise SyntaxError(f'Syntax error in argument: {a}')
             key = a[2:] if a[:2] == '--' else a[1:]
